/* Developed for Lenovo Educational Board Pass 3
   © Lenovo Created by Joshua Grosser
   v. 2.0 */

// define button, LED, and buzzer pins
#define BUZZER 11
#define YELLOW 16
#define GREEN 15
#define BLUE 18
#define Button1 4
#define Button2 5
#define Button3 6
#define MODE 7

// create the notes to play
int myChords [][3] = {
  {440, 555, 660}, // A Major
  {523, 660, 784}, // C Major
  {392, 494, 588}, // G Major
};

int myLED[3] = {YELLOW, GREEN, BLUE}; // Yellow = A Major,
// Green = C Major, Blue = G Major
// button states and modes
int mode_select = 0;
int Button1_State = 0;
int Button2_State = 0;
int Button3_State = 0;
int MODE_State = 0;

void setup(){
  Serial.begin(115200);
  // set the modes for buttons, LEDS, and buzzer
  pinMode(YELLOW, OUTPUT);
  pinMode(GREEN, OUTPUT);
  pinMode(BLUE, OUTPUT);
  pinMode(MODE, INPUT);
  pinMode(Button1, INPUT);
  pinMode(Button2, INPUT);
  pinMode(Button3, INPUT);
  pinMode(BUZZER, OUTPUT);

  // initialize the LED display
  int i = mode_select % 3;
  digitalWrite(myLED[i], HIGH);
}

void loop(){
  // determine chord to play based on mode
  int n = mode_select % 3;
  int note1 = myChords[n][0];
  int note2 = myChords[n][1];
  int note3 = myChords[n][2];
  MODE_State = digitalRead(MODE);
  // play different notes based off mode selected by button at pin 4
  if (MODE_State) // then change the current LED and the cords stored
  {
    delay(250);
    mode_select++;
    digitalWrite(myLED[n], LOW);
    n = mode_select % 3;
    digitalWrite(myLED[n], HIGH);
  }
  // play different note in cord based on button number
  if (digitalRead(Button1) == HIGH)
  {
    myTone(BUZZER, note1, 250); 
  }
  if (digitalRead(Button2) == HIGH)
  {
    myTone(BUZZER, note2, 250); 
  }
  if (digitalRead(Button3) == HIGH)
  {
    myTone(BUZZER, note3, 250); 
  }
  return;
}

// plays the tone we want by using the vibrations of the buzzer
void myTone(byte pin, uint16_t frequency, uint16_t duration) 
{ // input parameters: Arduino pin number, frequency in Hz, duration in milliseconds
  unsigned long startTime=millis();
  unsigned long halfPeriod= 1000000L/frequency/2;
  while (millis()-startTime< duration)
  {
    digitalWrite(pin,HIGH);
    delayMicroseconds(halfPeriod);
    digitalWrite(pin,LOW);
    delayMicroseconds(halfPeriod);
  }
}
